Index: src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java
===================================================================
--- src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java	(revision 4721)
+++ src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java	(working copy)
@@ -220,6 +220,12 @@
 		lineAdder = line -> {
 			if (line instanceof MapRoad) {
 				prefixSuffixFilter.filter((MapRoad) line);
+				if (!line.isDirection() && ((MapRoad) line).getRoadDef().isOneway()) {
+					// we want to set the direction flag for oneway roads because Garmin maps also do it 
+					// do this very late so that overlays are not modified 
+					line.setDirection(true); 
+				}
+								
 				collector.addRoad((MapRoad) line);
 			} else {
 				collector.addLine(line);
@@ -234,16 +240,14 @@
 		// undocumented option - usually used for debugging only
 		mergeRoads = !props.getProperty("no-mergeroads", false);
 		allowReverseMerge = props.getProperty("allow-reverse-merge", false);
-		if (allowReverseMerge) {
-			final String typesOption = "line-types-with-direction";
-			String typeList = props.getProperty(typesOption, "");
-			if (typeList.isEmpty())
-				typeList = style.getOption(typesOption);
-			List<String> types = CommandArgs.stringToList(typeList, typesOption);
-			for (String type :types) {
-				if (!type.isEmpty()) {
-					lineTypesWithDirection.add(Integer.decode(type));
-				}
+		final String typesOption = "line-types-with-direction";
+		String typeList = props.getProperty(typesOption, "");
+		if (typeList.isEmpty())
+			typeList = style.getOption(typesOption);
+		List<String> types = CommandArgs.stringToList(typeList, typesOption);
+		for (String type :types) {
+			if (!type.isEmpty()) {
+				lineTypesWithDirection.add(Integer.decode(type));
 			}
 		}
 		routable = props.containsKey("route");
@@ -363,13 +367,13 @@
 			ConvertedWay cw = new ConvertedWay(way, foundType);
 			cw.setReversed(wasReversed);
 
-			if (cw.isOneway() || way.tagIsLikeYes(TKM_HAS_DIRECTION)
-					|| lineTypesWithDirection.contains(foundType.getType()))
+			// evaluate special tag and list, list has lower priority 
+			if (way.tagIsLikeYes(TKM_HAS_DIRECTION)
+					|| (!way.tagIsLikeNo(TKM_HAS_DIRECTION) && lineTypesWithDirection.contains(foundType.getType()))) {
 				cw.setHasDirection(true);
-			if (way.tagIsLikeNo(TKM_HAS_DIRECTION)) 
-				cw.setHasDirection(false);
+			}
 			
-			if (cw.isRoad()){
+			if (cw.isRoad()) {
 				if (way.getId() == lastRoadId) {
 					for (int i = roads.size() - 1; i >= 0; i--) {
 						ConvertedWay prevRoad = roads.get(i);
@@ -1275,8 +1279,7 @@
 			line.setType(replType);
 		line.setPoints(points);
 
-		if (cw.isOneway() || cw.hasDirection())
-			line.setDirection(true);
+		line.setDirection(cw.hasDirection()); // used to check oneway as well
 
 		clipper.clipLine(line, lineAdder);
 	}
@@ -1883,7 +1886,7 @@
 		if (cw.isOneway()) {
 			road.setOneway();
 		}
-		road.setDirection(cw.isOneway() || cw.hasDirection());
+		road.setDirection(cw.hasDirection()); // ignore oneway here 
 
 		road.setAccess(cw.getAccess());
 		
Index: test/resources/rules/or-at-end.test
===================================================================
--- test/resources/rules/or-at-end.test	(revision 4721)
+++ test/resources/rules/or-at-end.test	(working copy)
@@ -2,13 +2,13 @@
 WAY
 highway=tertiary
 name=b
-oneway=1
+oneway=yes
 cycleway=opposite
 
 WAY 2
 highway=tertiary
 name=b
-oneway=1
+oneway=yes
 cycleway=opposite_lane
 
 
@@ -17,7 +17,7 @@
 	& oneway=*
 	& (cycleway=opposite | cycleway=opposite_lane | cycleway=opposite_track )
 	{ set name='a${name}' }
-	[0x2 ]
+	[0x2 road_class=1]
 
 
 <finalize>
@@ -24,7 +24,7 @@
 highway=* {name '${name}' }
 
 <<<results>>>
-WAY 1: Line 0x2, labels=[ab, null, null, null], res=24-24 oneway (1/1),(2/2),
-WAY 2: Line 0x2, labels=[ab, null, null, null], res=24-24 oneway (1/1),(2/2),
+WAY 1: Road 0x2, labels=[ab, null, null, null], res=24-24 oneway (1/1),(2/2), road class=1 speed=0
+WAY 2: Road 0x2, labels=[ab, null, null, null], res=24-24 oneway (1/1),(2/2), road class=1 speed=0
 
 
